<template>
  <div id="account-detail" class="p-4 mb-5 pb-5" role="tabpanel">
    <div class="row justify-content-center">
      <div class="col-lg-8">
        <h3 class="d-flex align-items-center mb-3">
          <i class="fa-solid fa-pen-to-square ms-2"></i>
          <span>{{ t('account.business.edit.title') }}</span>
        </h3>
        <hr class="border-black mt-3 mb-4"/>
        <p class="text-muted lh-lg">{{ t('account.business.edit.description') }}</p>
      </div>
    </div>

    <form class="row  justify-content-center" @submit.prevent="submitForm">
      <div class="col-lg-8">
        <div class="row">
          <div class="mb-3 col-lg-6">
            <label class="mb-2 fw-bold" for="logo">
              <i class="fa-regular d-block fa-image ms-1"></i>
              {{ t('account.business.edit.fields.logo', {name: data.type?.title || ''}) }}
            </label>
            <img :src="data.form.image" class="img-fluid d-block rounded w-100-px my-2" alt="">
            <input id="logo" class="form-control py-3" type="file" @change="uploadImage"/>
          </div>

          <div class="mb-3 col-lg-6 d-flex align-items-end">
            <div class="w-100">
              <label class="mb-2 fw-bold" for="name">
                <i class="fa-regular fa-circle-user ms-1"></i>
                {{ t('account.business.edit.fields.full_name') }}
              </label>
              <form-input id="name" v-model="data.form.name"/>
            </div>
          </div>

          <div class="mb-3 col-lg-6">
            <label class="mb-2 fw-bold" for="melicode">
              <i class="fa-solid fa-image-portrait ms-1"></i>
              {{ t('account.business.edit.fields.national_code') }}
            </label>
            <form-input id="melicode" dir="ltr" v-model="data.form.melicode"/>
          </div>

          <div class="mb-3 col-lg-6">
            <label class="mb-2 fw-bold" for="email">
              <i class="fa-regular fa-envelope ms-1"></i>
              {{ t('account.business.edit.fields.email') }}
            </label>
            <form-input id="email" dir="ltr" v-model="data.form.email"/>
          </div>

          <div class="mb-3 col-lg-6">
            <label class="mb-2 fw-bold" for="title">
              <i class="fa-solid fa-briefcase"></i>
              {{ t('account.business.edit.fields.business_name', {name: data.type?.title || ''}) }}
            </label>
            <form-input id="title" v-model="data.form.title"/>
          </div>

          <div class="mb-3 col-lg-6">
            <label class="mb-2 fw-bold" for="tel">
              <i class="fa-solid fa-phone ms-1"></i>
              {{ t('account.business.edit.fields.business_phone', {name: data.type?.title || ''}) }}
            </label>
            <form-input id="tel" dir="ltr" v-model="data.form.tel"/>
          </div>
          <div class="mb-3 col-lg-12">
            <label class="mb-2 fw-bold" for="address">
              <i class="fa-solid fa-location-dot ms-1"></i>
              {{ t('account.business.edit.fields.address') }}
            </label>
            <form-input id="address" v-model="data.form.address"/>
          </div>

          <div class="mb-4 col-lg-12">
            <label class="mb-2 fw-bold d-block">
              <i class="fa-regular fa-image ms-1"></i>
              انتخاب پس‌زمینه
            </label>
            <div class="d-flex flex-wrap gap-3">
              <div
                  v-for="(background,index) in data.backgrounds"
                  :key="index"
                  class="bg-option position-relative p-2"
                  :class="{ selected: data.form.background_id === background.id }"
                  @click="data.form.background_id = background.id"
              >
                <img :src="background.path" alt="background"/>
                <i
                    v-if="data.form.background_id === background.id"
                    class="fa-solid fa-circle-check selected-icon"
                ></i>
              </div>
            </div>
          </div>

          <div class="mb-5 pb-3 col-lg-12">
            <label class="mb-2 fw-bold" for="content">
              <i class="fa-solid fa-circle-info ms-1"></i>
              {{ t('account.business.edit.fields.about', {name: data.type?.title || ''}) }}
            </label>
            <client-only>
              <form-editor v-if="data.editor_loaded" v-model="data.form.content"/>
            </client-only>
          </div>

          <div class="mt-5 col-lg-12">
            <button class="btn btn-default w-100 py-3" type="submit">
              {{ t('account.business.edit.fields.submit') }}
            </button>
          </div>
        </div>
      </div>
    </form>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n'
import {useAuthStore} from '~/stores/auth'
import {useCookie} from "nuxt/app";
import {useRoute, useRouter} from "vue-router";
import {onMounted, reactive} from "vue";

// Variable
const {t} = useI18n()
const route = useRoute();
const router = useRouter();
const {$api, $sweetalert} = useNuxtApp()
const authStore = useAuthStore()


// Data
const id = ref(route.params.id);

const data = reactive({
  form: {
    name: '',
    melicode: '',
    title: '',
    tel: '',
    email: '',
    image: '',
    address: '',
    content: '',
    background_id: "",
  },
  editor_loaded: false,
  background: {},
  backgrounds: [{id: 0, path: '/upload.png'}],
})

// Actions
const getBackground = async () => {
  await $api.post('/background', {}).then((value) => {
    data.backgrounds = [
      {
        id: 0,
        path: '/upload.png'
      },
      ...value.data.data
    ]
  })
}

const uploadImage = (event) => {
  data.form.image = event.target.files[0]
}

const getData = async () => {
  await $api.post('/user/business/show', {
    id: id.value,
  }).then((value) => {
    if (value.data?.status) {
      if(value.data.data.role == 'user') {
        router.push('/account/business')
      }

      Object.assign(data.form, value.data.data)
      data.type = value.data.data.business_type

      // مقداردهی از authStore
      data.form.name = authStore.user?.name || ''
      data.form.melicode = authStore.user?.melicode || ''
      data.form.email = authStore.user?.email || ''

      data.editor_loaded = true
    }
  })
}

const submitForm = async () => {
  let formData = new FormData()

  formData.append('id', id.value)
  formData.append('name', data.form.name)
  formData.append('melicode', data.form.melicode)
  formData.append('title', data.form.title)
  formData.append('tel', data.form.tel)
  formData.append('email', data.form.email)
  formData.append('image', data.form.image)
  formData.append('address', data.form.address)
  formData.append('content', data.form.content)
  formData.append('business_type_id', data.type?.id)
  formData.append('background_id', data.form.background_id)

  await $api.post('/user/business/update', formData).then((value) => {
    if (value.data?.status) {
      $sweetalert.success(t('account.business.edit.success'))
      router.push('/account/business')
    } else {
      $sweetalert.error(t('account.business.edit.failed'))
    }
  })
}

// Life Cycle
onMounted(() => {
  getData().then(() => {
    getBackground()
  })
})
</script>


<style scoped>
.bg-option {
  width: 150px;
  height: 120px;
  border: 2px solid transparent;
  border-radius: 8px;
  overflow: hidden;
  cursor: pointer;
  transition: 0.3s ease-in-out;
  position: relative;
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.1);
}

.bg-option img {
  width: 100%;
  height: 100%;
  object-fit: cover;
}

.bg-option:hover {
  border-color: #0d6efd;
}

.bg-option.selected {
  border-color: #ff9800;
  box-shadow: 0 0 2px #ff9800;
}

.selected-icon {
  position: absolute;
  top: 6px;
  left: 6px;
  font-size: 18px;
  color: #ff9800;
  background-color: #fff;
  border-radius: 50%;
  padding: 2px;
}
</style>
  